@@ -22,13 +22,15 @@ __credits__ = [
 	"demurgos <https://github.com/demurgos>",
 	"ghickman <https://github.com/ghickman>",
 	"nvie <https://github.com/nvie>",
+	"adrienverge <https://github.com/adrienverge>",
+	"AndersBlomdell <https://github.com/AndersBlomdell>",
 ]
 __email__ = "cpburnz@gmail.com"
 __license__ = "MPL 2.0"
 __project__ = "pathspec"
 __status__ = "Development"
-__updated__ = "2017-04-04"
-__version__ = "0.5.2"
+__updated__ = "2017-07-01"
+__version__ = "0.5.3"
 
 from .pathspec import PathSpec
 from .pattern import Pattern, RegexPattern
@@ -39,4 +41,4 @@ from . import patterns
 
 # Expose `GitIgnorePattern` class in the root module for backward
 # compatibility with v0.4.
-from .patterns.gitwildmatch import GitIgnorePattern
\ No newline at end of file
+from .patterns.gitwildmatch import GitIgnorePattern
